@@ -1,6 +1,6 @@
 package App::Greple::xlate;
 
-our $VERSION = "0.33";
+our $VERSION = "0.34";
 
 =encoding utf-8
 
@@ -16,14 +16,14 @@ App::Greple::xlate - translation support module for greple
 
 =head1 VERSION
 
-Version 0.33
+Version 0.34
 
 =head1 DESCRIPTION
 
 B<Greple> B<xlate> module find desired text blocks and replace them by
 the translated text.  Currently DeepL (F<deepl.pm>) and ChatGPT
 (F<gpt3.pm>) module are implemented as a back-end engine.
-Experimental support for gpt-4 is also included.
+Experimental support for gpt-4 and gpt-4o are also included.
 
 If you want to translate normal text blocks in a document written in
 the Perl's pod style, use B<greple> command with C<xlate::deepl> and
@@ -83,6 +83,11 @@ Remove white space at the beginning and end of each line.
 
 =item *
 
+If a line ends with a full-width punctuation character, concatenate
+with next line.
+
+=item *
+
 If a line ends with a full-width character and the next line begins
 with a full-width character, concatenate the lines.
 
@@ -163,6 +168,23 @@ Specifies the translation engine to be used. If you specify the engine
 module directly, such as C<-Mxlate::deepl>, you do not need to use
 this option.
 
+At this time, the following engines are available
+
+=over 2
+
+=item * B<deepl>: DeepL API
+
+=item * B<gpt3>: gpt-3.5-turbo
+
+=item * B<gpt4>: gpt-4-turbo
+
+=item * B<gpt4o>: gpt-4o-mini
+
+B<gpt-4o>'s interface is unstable and cannot be guaranteed to work
+correctly at the moment.
+
+=back
+
 =item B<--xlate-labor>
 
 =item B<--xlabor>
@@ -181,6 +203,11 @@ C<deepl languages> command when using B<DeepL> engine.
 
 Specify the output format for original and translated text.
 
+The following formats other than C<xtxt> assume that the part to be
+translated is a collection of lines.  In fact, it is possible to
+translate only a portion of a line, and specifying a format other than
+C<xtxt> will not produce meaningful results.
+
 =over 4
 
 =item B<conflict>, B<cm>
@@ -234,6 +261,13 @@ API (B<--xlate>) and 5000 for the clipboard interface
 (B<--xlate-labor>).  You may be able to change these value if you are
 using Pro service.
 
+=item B<--xlate-maxline>=I<n> (Default: 0)
+
+Specify the maximum lines of text to be sent to the API at once.
+
+Set this value to 1 if you want to translate one line at a time.  This
+option takes precedence over the C<--xlate-maxlen> option.
+
 =item B<-->[B<no->]B<xlate-progress> (Default: True)
 
 See the tranlsation result in real time in the STDERR output.
@@ -488,9 +522,11 @@ our %opt = (
     method   => \(our $cache_method //= $ENV{GREPLE_XLATE_CACHE} || 'auto'),
     dryrun   => \(our $dryrun = 0),
     maxlen   => \(our $max_length = 0),
+    maxline  => \(our $max_line = 0),
     prompt   => \(our $prompt),
     mask     => \(our $mask),
     maskfile => \(our $maskfile),
+    glossary => \(our $glossary),
 );
 lock_keys %opt;
 sub opt :lvalue { ${$opt{+shift}} }
@@ -580,6 +616,8 @@ sub normalize {
 	${^MATCH}
 	# remove leading/trailing spaces
 	    =~ s/\A\s+|\s+\z//gr
+	# remove newline after Japanese Punct char
+	    =~ s/(?<=\p{InFullwidth})(?<=\pP)\n//gr
 	# join Japanese lines without space
 	    =~ s/(?<=\p{InFullwidth})\n(?=\p{InFullwidth})//gr
 	# join ASCII lines with single space
@@ -766,7 +804,9 @@ builtin xlate-cache:s      $cache_method
 builtin xlate-engine=s     $xlate_engine
 builtin xlate-dryrun       $dryrun
 builtin xlate-maxlen=i     $max_length
+builtin xlate-maxline=i    $max_line
 builtin xlate-prompt=s     $prompt
+builtin xlate-glossary=s   $glossary
 
 builtin deepl-auth-key=s   $App::Greple::xlate::deepl::auth_key
 builtin deepl-method=s     $App::Greple::xlate::deepl::method
