@@ -1,6 +1,6 @@
 package App::Greple::xlate::gpt4;
 
-our $VERSION = "0.33";
+our $VERSION = "0.34";
 
 use v5.14;
 use warnings;
@@ -23,8 +23,10 @@ my %param = (
     gpt3 => { engine => 'gpt-3.5-turbo', temp => '0.0', max => 3000, sub => \&gpty,
 	      prompt => 'Translate following entire text into %s, line-by-line.',
 	  },
-    gpt4 => { engine => 'gpt-4-1106-preview', temp => '0.0', max => 3000, sub => \&gpty,
-	      prompt => 'Translate following entire text into %s, line-by-line.',
+    gpt4 => { engine => 'gpt-4-turbo', temp => '0.0', max => 3000, sub => \&gpty,
+	      prompt => "Translate following entire text into %s, line-by-line.\n"
+		      . "Leave XML style tag as it is.\n"
+		      ,
 	  },
 );
 
